#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-fix
version:              0.3.4
visibility:           public
id:                   data-fix-0.3.4-7RS64eS6UJG1GL0dnQGMU4
key:                  data-fix-0.3.4-7RS64eS6UJG1GL0dnQGMU4
license:              BSD-3-Clause
maintainer:           <anton.kholomiov@gmail.com>
author:               Anton Kholomiov, Edward Kmett, Oleg Grenrus
stability:            Experimental
homepage:             https://github.com/spell-music/data-fix
synopsis:             Fixpoint data types
description:
    Fixpoint types and recursion schemes. If you define your AST as
    fixpoint type, you get fold and unfold operations for free.

    Thanks for contribution to: Matej Kollar, Herbert Valerio Riedel

category:             Data
abi:                  ebe02410093aa910230ec966feb73847
exposed:              True
exposed-modules:      Data.Fix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/data-fix-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-fix
hs-libraries:         HSdata-fix-0.3.4-7RS64eS6UJG1GL0dnQGMU4
depends:
    base-4.18.2.1 deepseq-1.4.8.1
    hashable-1.4.7.0-IVKAR4D6WU9H8t6zzGQ76p

haddock-interfaces:   /usr/share/doc/haskell-data-fix/html/data-fix.haddock
haddock-html:         /usr/share/doc/haskell-data-fix/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

